==> box-0.2.0.tar.gz: box-0.2.0/box/tokenizer.h <==
/***************************************************************************
 *   Copyright (C) 2006 by Matteo Franchin                                 *
 *   fnch@libero.it                                                        *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

/* $Id$ */

/** @file tokenizer.h
 * @brief The tokenizer for the Box language.
 *
 * This file declares the function used for the lexical analysis of Box
 * sources, which is done using flex.
 */

#ifndef _TOKENIZER_H
#  define _TOKENIZER_H

#  include "srcpos.h"
#  include "ast.h"

/** Variable to be used by the parser to get the current token position */
extern BoxSrc *tok_src;

int yylex(void);
Task Tok_Init(FILE *in, const char *f);
void Tok_Finish(void);
Task Tok_Include_Begin(const char *f);
UInt Tok_Include_End(void);

#endif /* _TOKENIZER_H */

==> box-0.2.3.tar.gz: box-0.2.3/box/tokenizer.h <==
/***************************************************************************
 *   Copyright (C) 2006 by Matteo Franchin                                 *
 *   fnch@libero.it                                                        *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

/* $Id$ */

/** @file tokenizer.h
 * @brief The tokenizer for the Box language.
 *
 * This file declares the function used for the lexical analysis of Box
 * sources, which is done using flex.
 */

#ifndef _TOKENIZER_H
#  define _TOKENIZER_H

#  include "srcpos.h"
#  include "ast.h"

/** Variable to be used by the parser to get the current token position */
extern BoxSrc *tok_src;

int yylex(void);
Task Tok_Init(FILE *main_file, const char *main_filename,
              const char *pre_filename);
BoxSrcName *Tok_Finish(void);
Task Tok_Include_Begin(const char *f);
UInt Tok_Include_End(void);

#endif /* _TOKENIZER_H */
